@@ -280,6 +280,12 @@ def create_global_exports(global_exports):
       continue
 
     v = int(v)
+
+    if not settings.MEMORY64:
+      # We assume that global exports are addresses, which need to be interpreted as unsigned.
+      # This is not necessary (and does not work) under wasm64 when the globals are i64.
+      v = v & 0xFFFFFFFF
+
     if settings.RELOCATABLE:
       v += settings.GLOBAL_BASE
     mangled = asmjs_mangle(k)
@@ -893,7 +899,7 @@ def install_debug_wrapper(sym):
   # The emscripten stack functions are called very early (by writeStackCookie) before
   # the runtime is initialized so we can't create these wrappers that check for
   # runtimeInitialized.
-  if sym.startswith(('_asan_', 'emscripten_stack_', '_emscripten_stack_')):
+  if sym.startswith(('__asan_', 'emscripten_stack_', '_emscripten_stack_')):
     return False
   # Likewise `__trap` can occur before the runtime is initialized since it is used in
   # abort.
